IntoWalkResult

Trait IntoWalkResult 

pub trait IntoWalkResult {
    // Required method
    fn into_walk_result(self) -> Result<WalkResult>;
}
Convert either an infallible or fallible typed handler result.

This keeps simple handlers terse while allowing a handler to return tvm_ffi::Result<WalkResult> and use ?.

Required Methods

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors