pub struct InplaceValue<'a> { /* private fields */ }Expand description
Engine-issued permission to attempt in-place mutation of one value.
The engine issues it only when the current ownership path permits reuse.
Implementations
Sourceimpl<'a> InplaceValue<'a>
impl<'a> InplaceValue<'a>
Methods from Deref<Target = MapValue>
Sourcepub fn cast<R: AnyCompatible>(&self) -> Option<R>
pub fn cast<R: AnyCompatible>(&self) -> Option<R>
Convert the value into an owned typed handle.
Sourcepub fn type_index(&self) -> i32
pub fn type_index(&self) -> i32
Runtime type index stored in this value.
Sourcepub fn as_node<N: ObjectCore>(&self) -> Option<&N>
pub fn as_node<N: ObjectCore>(&self) -> Option<&N>
Borrow the value as node type N if it is an instance of that type.