pub enum WalkResult {
Advance,
Skip,
Interrupt,
InterruptWith(Any),
}Expand description
What a callback asks the Rust walker to do with the current value.
Variants
Advance
Continue and visit this value’s children.
Skip
Continue without visiting this value’s children or firing its exit hook.
Interrupt
Halt the entire traversal.
InterruptWith(Any)
Halt the entire traversal and return a payload to the caller.
Implementations
Sourceimpl WalkResult
impl WalkResult
Sourcepub fn interrupt_with<T: Into<Any>>(payload: T) -> Self
pub fn interrupt_with<T: Into<Any>>(payload: T) -> Self
Halt traversal with an FFI-compatible payload.