macro_rules! cached_global_func {
($name:literal) => { ... };
}Expand description
Resolves a registered global Function by name
and caches it for the lifetime of the process (lock-free after the first
lookup). Each call site gets its own cache and the macro evaluates to a
&'static Function. Panics — naming the function — if it is not registered.
Usage: cached_global_func!("ffi.Map").call_packed(args)