with_stream

Function with_stream 

pub unsafe fn with_stream<T>(
    device: &DLDevice,
    stream: TVMFFIStreamHandle,
    f: impl FnOnce() -> Result<T>,
) -> Result<T>
Call f with the device stream temporarily set to stream.

Safety

stream must be a valid stream handle for the given device, or null.